// src/EChartsComponent.tsx
import * as echarts from "echarts";
import {
  memo,
  useRef,
  forwardRef,
  useImperativeHandle,
  useState,
  useEffect,
  useMemo
} from "react";

// src/IsomorphicResizeObserver.tsx
var ResizeObservePolyfill = class {
  constructor(callback) {
    this.callback = callback;
  }
  observe(target) {
    this.callback([{ contentRect: { width: target.clientWidth, height: target.clientHeight } }]);
  }
  disconnect() {
  }
};
var IsomorphicResizeObserver = typeof ResizeObserver !== "undefined" ? ResizeObserver : ResizeObservePolyfill;

// src/EChartsComponent.tsx
import { jsx } from "react/jsx-runtime";
var EChartsComponent = memo(
  forwardRef(function EChartsWrapper(props, ref) {
    const { option, opts, theme, initOpts, onInit, onUpdate, onResize, ...htmlProps } = props;
    const containerRef = useRef(null);
    const instanceRef = useRef(null);
    const [instance, setInstance] = useState();
    useImperativeHandle(ref, () => containerRef.current, []);
    const [height, setHeight] = useState(0);
    const [width, setWidth] = useState(0);
    const observer = useMemo(
      () => new IsomorphicResizeObserver((entries) => {
        if (entries[0]) {
          const { width: width2, height: height2 } = entries[0].contentRect;
          setHeight(height2);
          setWidth(width2);
          if (height2 > 0 && width2 > 0) {
            if (!instanceRef.current && containerRef.current) {
              const instance2 = echarts.init(containerRef.current, theme, initOpts);
              instanceRef.current = instance2;
              setInstance(instance2);
              onInit?.(instance2, width2, height2);
            }
          }
        }
      }),
      []
    );
    useEffect(() => {
      if (containerRef.current) {
        observer.observe(containerRef.current);
      }
      return () => {
        observer.disconnect();
        instanceRef.current?.dispose();
        instanceRef.current = null;
      };
    }, []);
    const updateRef = useRef();
    useEffect(() => {
      updateRef.current = onUpdate;
    }, [onUpdate]);
    useEffect(() => {
      if (instance && option) {
        instance.setOption(option, opts);
        updateRef.current?.(instance, option, opts);
      }
    }, [instance, option]);
    const resizeRef = useRef();
    useEffect(() => {
      resizeRef.current = onResize;
    }, [onResize]);
    useEffect(() => {
      if (instanceRef.current) {
        instanceRef.current.resize({
          width,
          height
        });
        resizeRef.current?.(instanceRef.current, width, height);
      }
    }, [width, height]);
    return /* @__PURE__ */ jsx("div", { ref: containerRef, ...htmlProps });
  })
);

// src/index.tsx
var src_default = EChartsComponent;
export {
  EChartsComponent,
  src_default as default
};
